# mosamatic
Desktop application for body composition analysis


## chatgpt
https://chatgpt.com/c/677d0780-83e4-800b-bd73-b4543a6c10f7


## project structure
- root
    - mosamatic
        - __init__.py
        - core
            - __init__.py
            - controller.py
            - models.py
            - tasks.py
            - utils.py
        - ui
            - __init__.py
            - tk.py
            - wx.py
            - cli.py
            - base.py
        - tests
            - __init__.py
            - test_core.py
            - test_ui.py
            - test_cli.py
        - docs
            - index.md
        - examples
            - example.py
        - main.py
        - cli.py
    - requirements.txt
    - pyproject.toml
    - MANIFEST.in
